#!/bin/ksh
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
#
# Copyright IBM Corp. 2010 All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#  Description: Application Support Installer wrapper script
#
#  Parameters:
#    CANDLEHOME, set in the environment
#    -h {full path to ITM home}
#    -silent - perform a silent install
#    -r {response file}
#
#  Returns:
#    None
#============================================================
#set -x

usage()
{
  echo ""
  echo "Usage:"
  echo "  itmasi.sh [-h {ITM home}] [-silent] [-r {response file}] [-j {JAVAHOME}]"
  echo ""
  echo "where"
  echo "" 
  echo "-h       Specifies the ITM installation directory, uses"
  echo "         CANDLEHOME if -h not specified."
  echo "-silent  Specifies silent install using a response file."
  echo "-r       Specifies a fully qualified path to a response file,"
  echo "         uses response.txt if -r not specified."
  echo "-j       Specifies the JAVAHOME directory, uses"
  echo "         JAVAHOME if not specified."
  echo ""
  echo "Default trace log location: /tmp"
  exit 1
}

# Parse the input parameters
while [ $# -gt 0 ]
do
  case $1 in
    -h) 
      if [ -d $2/tmaitm6 ]; then
        CANDLEHOME=$2
      else
        echo "ITM home is not a valid path, the installation has been aborted..."
        exit 1
      fi
      shift
      shift
      ;;
    -j) 
      if [ -f $2/bin/java ]; then
        JAVAHOME=$2
      else
        echo "JAVAHOME is not a valid path to $2/bin/java, the installation has been aborted..."
        exit 1
      fi
      shift
      shift
      ;;
    -silent)
      SILENT=$1
      shift
      ;;
    -r)
      if [ -f "$2" ]; then
        RESPONSE=$2
      else
        echo "response file: $2 not found, the installation has been aborted..."
        exit 1
      fi
      shift
      shift
      ;;
    --)
      shift
      break
      ;;
    -*)
      usage
      ;;
    *)
      usage
      ;;
  esac
done

# ask for the ITM install directory if not in the environment
if [ ! -d $CANDLEHOME/tmaitm6 ]; then
  if [ "$SILENT" = "-silent" ]; then
    echo "ITM home is not a valid path, the installation has been aborted..."
    exit 1
  fi 
  while true
  do
    echo "Enter the path of the IBM Tivoli Monitoring directory or q to quit:"
    read CANDLEHOME
    if [ "${CANDLEHOME}" = "q" ]; then
      echo "itmasi.sh exiting..."
      exit 1
    fi
    if [ -d $CANDLEHOME/tmaitm6 ]; then
      export CANDLEHOME
      break
    else
      echo "$CANDLEHOME/tmaitm6 was not found..."
    fi
  done
fi

# Find JAVAHOME
if [ "$JAVAHOME" = "" ]; then
  JAVAHOME=`$CANDLEHOME/bin/CandleGetJavaHome`
else
  if [ ! -f $JAVAHOME/bin/java ]; then
    echo "JAVAHOME is not a valid path to $JAVAHOME/bin/java, the installation has been aborted..."
    exit 1
  fi
fi

if [ "$SILENT" != "-silent" ]; then
  echo "Are you sure you want to install the patch using JAVAHOME=$JAVAHOME, enter (y/n):"
  read ANS
  if [ "${ANS}" = "n"  ]; then
    exit 1
  fi
fi

if [ "$SILENT" != "-silent" ]; then
  echo "Executing: $JAVAHOME/bin/java -jar setup.jar"
  $JAVAHOME/bin/java -jar setup.jar
  echo "Trace log location: /tmp"
else
  if [ "$RESPONSE" = "" ]; then
    RESPONSE=$PWD/response.tmp
    # Update the response.txt file with CANDLEHOME and patch path
    rm -f $RESPONSE
    sed -e "s%-W Directories\.itmhome=.*%-W Directories\.itmhome=\"$CANDLEHOME\"%g" -e "s%-W Directories\.mediaLocation=.*%-W Directories\.mediaLocation=\"$PWD\"%g" $PWD/response.txt > $RESPONSE
  fi

  # Check for Linux and zLinux and setup bin file
  cArch=`( . $CANDLEHOME/bin/dynarch.shl $CANDLEHOME/registry/archdsc.tbl ; echo $cArch )` 
  if [[ "$cArch" = li+([0-9]) ]]
  then
    if [ ! -f $PWD/setupLinux.bin ]; then
      echo "=============================Notice======================================"
      echo "Using the silent install option for Linux Operating systems requires"
      echo "the setupLinux.bin binary file.  This file is not shipped with this fix"
      echo "and must be obtained with interim fix 6.2-TIV-ITM_ASI-IF0001.  Once"
      echo "the binary file is obtained by way of interim fix 6.2-TIV-ITM_ASI-IF0001,"
      echo "place it in the $PWD directory and re-run the install."
      echo "========================================================================="
      exit 1
    else
      if [ ! -x $PWD/setupLinux.bin ]; then
        chmod +x $PWD/setupLinux.bin
      fi
      echo "Executing: $PWD/setupLinux.bin -silent -options $RESPONSE"
      $PWD/setupLinux.bin -silent -options $RESPONSE
      echo "Trace log location: /tmp"
    fi
  elif [[ "$cArch" = lz+([0-9]) ]]
  then
    if [ ! -f $PWD/setupLinux390.bin ]; then
      echo "==============================Notice======================================"
      echo "Using the silent install option for Linux Operating systems requires"
      echo "the setupLinux390.bin binary file.  This file is not shipped with this fix"
      echo "and must be obtained with interim fix 6.2-TIV-ITM_ASI-IF0001.  Once"
      echo "the binary file is obtained by way of interim fix 6.2-TIV-ITM_ASI-IF0001,"
      echo "place it in the $PWD directory and re-run the install."
      echo "=========================================================================="
      exit 1
    else
      if [ ! -x $PWD/setupLinux390.bin ]; then
        chmod +x $PWD/setupLinux390.bin
      fi
      echo "Executing: $PWD/setupLinux390.bin -silent -options $RESPONSE"
      $PWD/setupLinux390.bin -silent -options $RESPONSE
      echo "Trace log location: /tmp"
    fi
  else
    echo "Executing: $JAVAHOME/bin/java -jar setup.jar -silent -options $RESPONSE"
    $JAVAHOME/bin/java -jar setup.jar -silent -options $RESPONSE
    echo "Trace log location: /tmp"
  fi
fi

exit 0
